summaryrefslogtreecommitdiffstats
path: root/src/kernel/qpngio.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/kernel/qpngio.cpp')
-rw-r--r--src/kernel/qpngio.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/kernel/qpngio.cpp b/src/kernel/qpngio.cpp
index a552461e..b90836ac 100644
--- a/src/kernel/qpngio.cpp
+++ b/src/kernel/qpngio.cpp
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
** Public Licensing retquirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
@@ -684,7 +684,7 @@ void write_png_image(TQImageIO* iio)
/*!
Creates an image packer that writes PNG data to IO device \a iod
using a \a storage_depth bit encoding (use 8 or 32, depending on
- the desired quality and compression retquirements).
+ the desired quality and compression requirements).
If the image needs to be modified to fit in a lower-resolution
result (e.g. converting from 32-bit to 8-bit), use the \a
@@ -925,7 +925,7 @@ class TQPNGFormatType : public TQImageFormatType
\ingroup io
This subclass of TQImageFormatType recognizes PNG format images, creating
- a TQPNGFormat when retquired. An instance of this class is created
+ a TQPNGFormat when required. An instance of this class is created
automatically before any other factories, so you should have no need for
such objects.
*/
@@ -18,7 +18,7 @@
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please